@@ -126,8 +126,9 @@ rank_leverage <- function(x) {
 #'   )
 #'
 #' titration |>
-#'   gf_point(OD ~ Riboflavin) |>
-#'   gf_smooth(col = "indianred3", se = TRUE, lwd = 0.5, method = "loess")
+#'   ggplot(aes(Riboflavin, OD)) +
+#'   geom_point(col = bmj[1]) +
+#'   geom_smooth(col = bmj[2], se = TRUE, lwd = 0.5, method = "loess")
 #'
 #' ## Model with intercept different from zero:
 #' model <- lm(OD ~ Riboflavin, data = titration)
@@ -360,3 +361,145 @@ pseudo_r2 <- function(model) {
   res <- data.frame(Index, Estimate)
   res
 }
+
+#' A theme for huxtables
+#' This function quickly set a default style for a huxtable.
+#' @param ht A huxtable object.
+#' @param rw A numeric vector with the rows on which a bottom border is desired.
+#' @details \code{theme_pubh} is a variation of \code{theme_article} with the added flexibility
+#' of adding a bottom border line at desired row numbers.
+#' @examples
+#' require(dplyr, quietly = TRUE)
+#' data(Oncho)
+#'
+#' Oncho |>
+#'   select(area, mf) |>
+#'   cross_tbl(by = "area") |>
+#'   theme_pubh(2)
+#'
+#' data(Bernard)
+#'
+#' t1 <- estat(~ apache | fate, data = Bernard)
+#' t2 <- estat(~ o2del | fate, data = Bernard)
+#' rbind(t1, t2) |>
+#'   as_hux() |>
+#'   theme_pubh(c(1, 3))
+#' @export
+theme_pubh <- function(ht, rw = 1) {
+  ht <- huxtable::set_all_borders(ht, 0)
+  ht <- huxtable::set_top_border(ht, 1, huxtable::everywhere)
+  ht <- huxtable::set_bottom_border(ht, huxtable::final(1), huxtable::everywhere)
+  ht <- huxtable::set_bottom_border(ht, rw, huxtable::everywhere)
+  ht <- huxtable::style_header_rows(ht, bold = TRUE)
+  ht
+}
+
+#' Cosmetics for summary tables
+#' Adds some cosmetics to tables of descriptive statistics generated by tbl_summary.
+#' @param gt_tbl A table object generated by \code{\link[gtsummary]{tbl_summary}}.
+#' @param pad Numerical, padding above and bellow rows.
+#' @param bold Display labels in bold?
+#' @param head_label Character, label to be used as head for the variable's column.
+#' @details Function \code{cosm_sum} adds some cosmetics to tables generated by \code{\link[gtsummary]{tbl_summary}}, then converts the table as a \code{\link[huxtable]{huxtable}} and sets proper alignment.
+#' @return A \code{\link[huxtable]{huxtable}}.
+#' @examples
+#' require(dplyr, quietly = TRUE)
+#'
+#' data(Oncho)
+#' Oncho |>
+#'   select(-id) |>
+#'   tbl_summary() |>
+#'   cosm_sum(bold = TRUE) |>
+#'   theme_pubh(1)
+#' @export
+cosm_sum <- function(gt_tbl, pad = 3, bold = FALSE, head_label = "**Variable**") {
+  tbl <- gt_tbl |>
+    gtsummary::modify_header(label ~ head_label) |>
+    gtsummary::modify_footnote(everything() ~ NA)
+
+  if (bold == FALSE) {
+    tbl <- tbl
+  } else {
+    tbl <- tbl |> gtsummary::bold_labels()
+  }
+
+  tbl <- tbl |>
+    gtsummary::as_hux_table() |>
+    huxtable::set_align(everywhere, -1, "right") |>
+    huxtable::set_top_padding(pad) |>
+    huxtable::set_bottom_padding(pad)
+
+  tbl
+}
+
+#' Cosmetics for tables of regression coefficients.
+#' Converts tables generated by \code{\link[gtsummary]{tbl_regression}} to \code{\link[huxtable]{huxtable}} and adds some cosmetics.
+#' @param gt_tbl A table object generated by \code{\link[gtsummary]{tbl_regression}}.
+#' @param pad Numerical, padding above and bellow rows.
+#' @param type Anova's type to calculate global p-values.
+#' @param bold Display labels in bold?
+#' @param head_label Character, label to be used as head for the variable's column.
+#' @return A \code{\link[huxtable]{huxtable}}.
+#' @examples
+#' require(sjlabelled, quietly = TRUE)
+#'
+#' data(diet, package = "Epi")
+#' diet <- diet |>
+#'   var_labels(
+#'     chd = "Coronary Heart Disease",
+#'     fibre = "Fibre intake (g/day)"
+#'   )
+#'
+#' model_binom <- glm(chd ~ fibre, data = diet, family = binomial)
+#'
+#' model_binom |>
+#'   tbl_regression(exponentiate = TRUE) |>
+#'   cosm_reg(bold = TRUE) |>
+#'   theme_pubh(1) |>
+#'   add_footnote(get_r2(model_binom), font_size = 9)
+#'
+#' data(birthwt, package = "MASS")
+#' birthwt <- birthwt |>
+#'   mutate(
+#'     smoke = factor(smoke, labels = c("Non-smoker", "Smoker")),
+#'     race = factor(race, labels = c("White", "African American", "Other"))
+#'   ) |>
+#'   var_labels(
+#'     bwt = "Birth weight (g)",
+#'     smoke = "Smoking status",
+#'     race = "Race"
+#'   )
+#'
+#' model_norm <- lm(bwt ~ smoke + race, data = birthwt)
+#'
+#' model_norm |>
+#'   tbl_regression() |>
+#'   cosm_reg(bold = TRUE) |>
+#'   theme_pubh(1) |>
+#'   add_footnote(get_r2(model_norm), font_size = 9)
+#' @export
+cosm_reg <- function(gt_tbl, pad = 3, type = 3, bold = TRUE, head_label = "**Variable**") {
+  tbl0 <- gt_tbl |>
+    gtsummary::modify_header(label ~ head_label) |>
+    gtsummary::modify_footnote(everything() ~ NA, abbreviation = TRUE)
+
+  if (is.null(type)) {
+    tbl <- tbl0
+  } else {
+    tbl <- tbl0 |> gtsummary::add_global_p(type = type)
+  }
+
+  if (bold == FALSE) {
+    tbl <- tbl
+  } else {
+    tbl <- tbl |> gtsummary::bold_labels()
+  }
+
+  tbl <- tbl |>
+    gtsummary::as_hux_table() |>
+    huxtable::set_align(everywhere, -1, "right") |>
+    huxtable::set_top_padding(pad) |>
+    huxtable::set_bottom_padding(pad)
+
+  tbl
+}
